package svc

import (
	"git.chillcy.com/golang/chillcy/pkg/etcd"
	"git.chillcy.com/golang/chillcy/project/pc4/pkg/rpc/client/product"
	"git.chillcy.com/golang/colorway/internal/pkg/database"
	"git.chillcy.com/golang/colorway/internal/rpc/internal/config"
	"github.com/zeromicro/go-zero/zrpc"
)

type ServiceContext struct {
	Config          config.Config
	DatabaseManager *database.Manager
	Pc4RpcService   Pc4RpcService
}

func NewServiceContext(c config.Config) *ServiceContext {
	etcd.Init(etcd.Env(c.Mode))
	// todo dsn etcd
	dsn := "root:root@tcp(127.0.0.1:3306)/colorway?charset=utf8mb4&collation=utf8mb4_unicode_ci&parseTime=true&loc=Local"
	manager, err := database.NewManager(dsn)
	if err != nil {
		panic(err)
	}
	// todo etcd config
	pc4RpcProductServiceTarget := "127.0.0.1:5100"
	return &ServiceContext{
		Config:          c,
		DatabaseManager: manager,
		Pc4RpcService: Pc4RpcService{
			Product: product.NewProduct(zrpc.MustNewClient(zrpc.RpcClientConf{Target: pc4RpcProductServiceTarget})),
		},
	}
}

type Pc4RpcService struct {
	Product product.Product
}
